Task: MS_MARCO
===============
Description: A large scale Machine Reading Comprehension Dataset with questions sampled from real anonymized user queries and contexts from web documents. From Nguyen et al. '16. 

Link: https://arxiv.org/abs/1611.09268

Tags: #MS_MARCO, #All, #QA

